@@ -1,8 +1,4 @@
-#![cfg(all(
-    any(feature = "2d", feature = "3d"),
-    not(all(feature = "2d", feature = "3d")),
-))]
-
+#![cfg(any(dim2, dim3))]
 use std::time::Duration;
 
 use bevy::core::CorePlugin;
@@ -11,10 +7,12 @@ use bevy::reflect::TypeRegistryArc;
 
 use heron_core::{CollisionShape, PhysicsSteps, RigidBody};
 use heron_rapier::convert::IntoBevy;
-use heron_rapier::rapier::dynamics::RigidBodySet;
-use heron_rapier::rapier::geometry::ColliderSet;
 use heron_rapier::RapierPlugin;
 
+use utils::*;
+
+mod utils;
+
 fn test_app() -> App {
     let mut builder = App::build();
     builder
@@ -60,16 +58,16 @@ fn can_use_child_entity_for_the_collision_shape() {
     assert_eq!(body.colliders(), &[collider_handle]);
     assert_eq!(body.position().into_bevy(), (Vec3::ZERO, Quat::IDENTITY));
 
-    assert_eq!(collider.parent(), body_handle);
+    assert_eq!(collider.parent(), Some(body_handle));
 
-    let (actual_translation, actual_rotation) = collider.position_wrt_parent().into_bevy();
+    let (actual_translation, actual_rotation) = collider.position().into_bevy();
 
-    #[cfg(feature = "2d")]
+    #[cfg(dim2)]
     assert_eq!(
         actual_translation,
         Vec3::new(translation.x, translation.y, 0.0)
     );
-    #[cfg(feature = "3d")]
+    #[cfg(dim3)]
     assert_eq!(actual_translation, translation);
 
     assert!((actual_rotation.x - rotation.x).abs() < 0.00001);
@@ -108,14 +106,14 @@ fn can_change_the_position_of_a_shape_inserted_in_child_entity() {
 
     let (_, collider) = colliders.iter().next().unwrap();
 
-    let (actual_translation, _) = collider.position_wrt_parent().into_bevy();
+    let (actual_translation, _) = collider.position().into_bevy();
 
-    #[cfg(feature = "2d")]
+    #[cfg(dim2)]
     assert_eq!(
         actual_translation,
         Vec3::new(translation.x, translation.y, 0.0)
     );
-    #[cfg(feature = "3d")]
+    #[cfg(dim3)]
     assert_eq!(actual_translation, translation);
 }
 
@@ -144,7 +142,7 @@ fn updating_local_transform_of_a_rigid_body_doesnt_affect_the_shape() {
 
     let (_, collider) = colliders.iter().next().unwrap();
 
-    let (actual_translation, _) = collider.position_wrt_parent().into_bevy();
+    let (actual_translation, _) = collider.position_wrt_parent().unwrap().into_bevy();
 
     assert_eq!(actual_translation, Vec3::default());
 }
